scilpy.io package
=================

scilpy.io.btensor module
------------------------

.. automodule:: scilpy.io.btensor
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.deprecator module
---------------------------

.. automodule:: scilpy.io.deprecator
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.fetcher module
------------------------

.. automodule:: scilpy.io.fetcher
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.gradients module
--------------------------

.. automodule:: scilpy.io.gradients
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.image module
----------------------

.. automodule:: scilpy.io.image
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.streamlines module
----------------------------

.. automodule:: scilpy.io.streamlines
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.tensor module
-----------------------

.. automodule:: scilpy.io.tensor
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.utils module
----------------------

.. automodule:: scilpy.io.utils
   :members:
   :undoc-members:
   :show-inheritance:

scilpy.io.varian\_fdf module
----------------------------

.. automodule:: scilpy.io.varian_fdf
   :members:
   :undoc-members:
   :show-inheritance:
